@@ -1,12 +1,8 @@
-from flask_dance.consumer import OAuth2ConsumerBlueprint, OAuth2Session
-from functools import partial
-from flask.globals import LocalProxy, _lookup_app_object
+from flask import g, request
+from werkzeug.local import LocalProxy
 
 from flask_dance import __version__ as _flask_dance_version
-
-from flask import request
-
-from flask import _app_ctx_stack as stack
+from flask_dance.consumer import OAuth2ConsumerBlueprint, OAuth2Session
 
 __maintainer__ = "Jimmy Hedman <jimmy.hedman@gmail.com>"
 
@@ -102,10 +98,9 @@ def make_strava_blueprint(
 
     @strava_bp.before_app_request
     def set_applocal_session():
-        ctx = stack.top
-        ctx.strava_oauth = strava_bp.session
+        g.flask_dance_strava = strava_bp.session
 
     return strava_bp
 
 
-strava = LocalProxy(partial(_lookup_app_object, "strava_oauth"))
+strava = LocalProxy(lambda: g.flask_dance_strava)
